==> qttranslations-opensource-src_5.1.0.orig.tar.xz: qttranslations-opensource-src-5.1.0/translations/qt_help_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>QCLuceneResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Suchergebnisse</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Achtung:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed!</source>
        <translation>Es können nicht alle möglichen Ergebnisse angezeigt werden, da die Dokumentation noch indiziert wird.</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Es wurden keine mit Ihrer Suche übereinstimmenden Dokumente gefunden.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Ein Grund dafür könnte sein, das die Dokumentation noch nicht vollständig indiziert ist.)</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Ohne Titel</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &apos;%1&apos; is not set up yet!</source>
        <translation>Die Katalogdatei &apos;%1&apos; ist noch nicht eingerichtet.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Der Datenbanktreiber für SQLite kann nicht geladen werden.</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Katalogdatei kann nicht geöffnet werden: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1!</source>
        <translation>In Datei %1 können keine Tabellen angelegt werden.</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; already exists!</source>
        <translation>Die Katalogdatei &apos;%1&apos; existiert bereits.</translation>
    </message>
    <message>
        <source>Unknown filter &apos;%1&apos;!</source>
        <translation>Unbekannter Filter &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Invalid documentation file &apos;%1&apos;!</source>
        <translation>Ungültige Dokumentationsdatei &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Cannot register namespace &apos;%1&apos;!</source>
        <translation>Der Namensraum &apos;%1&apos; kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Cannot open database &apos;%1&apos; to optimize!</source>
        <translation>Die Datenbank &apos;%1&apos; kann nicht zur Optimierung geöffnet werden.</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Das Verzeichnis kann nicht angelegt werden: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Die Katalogdatei kann nicht kopiert werden: %1</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Der Filter kann nicht registriert werden: %1</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1!</source>
        <translation>Die Dokumentationsdatei kann nicht geöffnet werden: %1</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered!</source>
        <translation>Der Namensraum %1 wurde nicht registriert.</translation>
    </message>
    <message>
        <source>Namespace %1 already exists!</source>
        <translation>Der Namensraum %1 existiert bereits.</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &apos;%1&apos; &apos;%2&apos;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>Kann Datenbank nicht öffnen: &apos;%1&apos; &apos;%2&apos;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpEngineCore</name>
    <message>
        <source>Cannot open documentation file %1: %2!</source>
        <translation>Die Dokumentationsdatei %1 kann nicht geöffnet werden: %2!</translation>
    </message>
    <message>
        <source>The specified namespace does not exist!</source>
        <translation>Der angegebene Namensraum existiert nicht.</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Invalid help data!</source>
        <translation>Ungültige Hilfe-Daten.</translation>
    </message>
    <message>
        <source>No output file name specified!</source>
        <translation>Für die Ausgabe-Datei wurde kein Name angegeben.</translation>
    </message>
    <message>
        <source>Building up file structure...</source>
        <translation>Dateistruktur wird erzeugt...</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten!</source>
        <translation>Die Datei %1 kann nicht überschrieben werden.</translation>
    </message>
    <message>
        <source>Cannot open data base file %1!</source>
        <translation>Die Datenbank-Datei %1 kann nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>Cannot register namespace %1!</source>
        <translation>Der Namensraum %1 kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Insert custom filters...</source>
        <translation>Benutzerdefinierte Filter einfügen...</translation>
    </message>
    <message>
        <source>Insert help data for filter section (%1 of %2)...</source>
        <translation>Hilfe-Daten für Filter-Sektion (%1 von %2) einfügen...</translation>
    </message>
    <message>
        <source>Documentation successfully generated.</source>
        <translation>Dokumentation erfolgreich generiert.</translation>
    </message>
    <message>
        <source>Some tables already exist!</source>
        <translation>Einige Tabellen existieren bereits.</translation>
    </message>
    <message>
        <source>Cannot create tables!</source>
        <translation>Tabellen können nicht erstellt werden.</translation>
    </message>
    <message>
        <source>Cannot register virtual folder!</source>
        <translation>Virtuelles Verzeichnis nicht registriert werden.</translation>
    </message>
    <message>
        <source>Insert files...</source>
        <translation>Dateien einfügen...</translation>
    </message>
    <message>
        <source>The file %1 does not exist! Skipping it.</source>
        <translation>Die Datei %1 existiert nicht. Wird übersprungen.</translation>
    </message>
    <message>
        <source>Cannot open file %1! Skipping it.</source>
        <translation>Die Datei %1 kann nicht geöffnet werden. Wird übersprungen.</translation>
    </message>
    <message>
        <source>The filter %1 is already registered!</source>
        <translation>Der Filter %1 ist bereits registriert.</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Der Filter %1 kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Insert indices...</source>
        <translation>Indizes einfügen...</translation>
    </message>
    <message>
        <source>Insert contents...</source>
        <translation>Inhalt einfügen...</translation>
    </message>
    <message>
        <source>Cannot insert contents!</source>
        <translation>Inhalt kann nicht eingefügt werden.</translation>
    </message>
    <message>
        <source>Cannot register contents!</source>
        <translation>Inhalt kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; does not exist.</source>
        <translation>Die Datei &apos;%1&apos; existiert nicht.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; cannot be opened.</source>
        <translation>Die Datei &apos;%1&apos; kann nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; contains an invalid link to file &apos;%2&apos;</source>
        <translation>Die Datei &apos;%1&apos; enthält einen ungültigen Verweis auf die Datei &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Invalid links in HTML files.</source>
        <translation>Es wurden ungültige Verweise in HTML-Dateien gefunden.</translation>
    </message>
</context>
<context>
    <name>QHelpProject</name>
    <message>
        <source>Unknown token.</source>
        <translation>Unbekanntes Token.</translation>
    </message>
    <message>
        <source>Unknown token. Expected &quot;QtHelpProject&quot;!</source>
        <translation>Unbekanntes Token. &quot;QtHelpProject&quot; erwartet.</translation>
    </message>
    <message>
        <source>Error in line %1: %2</source>
        <translation>Fehler in Zeile %1: %2</translation>
    </message>
    <message>
        <source>Virtual folder has invalid syntax.</source>
        <translation>Ungültige Syntax bei Angabe des virtuellen Verzeichnisses.</translation>
    </message>
    <message>
        <source>Namespace has invalid syntax.</source>
        <translation>Ungültige Syntax der Namensraum-Angabe.</translation>
    </message>
    <message>
        <source>Missing namespace in QtHelpProject.</source>
        <translation>Fehlender Namensraum in QtHelpProject.</translation>
    </message>
    <message>
        <source>Missing virtual folder in QtHelpProject</source>
        <translation>Fehlendes virtuelles Verzeichnis in QtHelpProject.</translation>
    </message>
    <message>
        <source>The input file %1 could not be opened!</source>
        <translation>Die Eingabe-Datei %1 kann nicht geöffnet werden.</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Suche nach:</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Vorige Suche</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Nächste Suche</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation>Erweiterte Suche</translation>
    </message>
    <message>
        <source>words &lt;B&gt;similar&lt;/B&gt; to:</source>
        <translation>Worte &lt;B&gt;ähnlich&lt;/B&gt; zu:</translation>
    </message>
    <message>
        <source>&lt;B&gt;without&lt;/B&gt; the words:</source>
        <translation>&lt;B&gt;ohne&lt;/B&gt; die Wörter:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;exact phrase&lt;/B&gt;:</source>
        <translation>mit der &lt;B&gt;genauen Wortgruppe&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;all&lt;/B&gt; of the words:</source>
        <translation>mit &lt;B&gt;allen&lt;/B&gt; Wörtern:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;at least one&lt;/B&gt; of the words:</source>
        <translation>mit &lt;B&gt;irgendeinem&lt;/B&gt; der Wörter:</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2 - Ein Treffer</numerusform>
            <numerusform>%1 - %2 von %n Treffern</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0 von 0 Treffern</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src-5.3.0.tar.xz: qttranslations-opensource-src-5.3.0/translations/qt_help_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QCLuceneResultWidget</name>
    <message>
        <source>Search Results</source>
        <translation>Suchergebnisse</translation>
    </message>
    <message>
        <source>Note:</source>
        <translation>Achtung:</translation>
    </message>
    <message>
        <source>The search results may not be complete since the documentation is still being indexed!</source>
        <translation>Es können nicht alle möglichen Ergebnisse angezeigt werden, da die Dokumentation noch indiziert wird.</translation>
    </message>
    <message>
        <source>Your search did not match any documents.</source>
        <translation>Es wurden keine mit Ihrer Suche übereinstimmenden Dokumente gefunden.</translation>
    </message>
    <message>
        <source>(The reason for this might be that the documentation is still being indexed.)</source>
        <translation>(Ein Grund dafür könnte sein, das die Dokumentation noch nicht vollständig indiziert ist.)</translation>
    </message>
</context>
<context>
    <name>QHelp</name>
    <message>
        <source>Untitled</source>
        <translation>Ohne Titel</translation>
    </message>
</context>
<context>
    <name>QHelpCollectionHandler</name>
    <message>
        <source>The collection file &apos;%1&apos; is not set up yet!</source>
        <translation>Die Katalogdatei &apos;%1&apos; ist noch nicht eingerichtet.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Der Datenbanktreiber für SQLite kann nicht geladen werden.</translation>
    </message>
    <message>
        <source>Cannot open collection file: %1</source>
        <translation>Katalogdatei kann nicht geöffnet werden: %1</translation>
    </message>
    <message>
        <source>Cannot create tables in file %1!</source>
        <translation>In Datei %1 können keine Tabellen angelegt werden.</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; already exists!</source>
        <translation>Die Katalogdatei &apos;%1&apos; existiert bereits.</translation>
    </message>
    <message>
        <source>Unknown filter &apos;%1&apos;!</source>
        <translation>Unbekannter Filter &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Invalid documentation file &apos;%1&apos;!</source>
        <translation>Ungültige Dokumentationsdatei &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Cannot register namespace &apos;%1&apos;!</source>
        <translation>Der Namensraum &apos;%1&apos; kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Cannot open database &apos;%1&apos; to optimize!</source>
        <translation>Die Datenbank &apos;%1&apos; kann nicht zur Optimierung geöffnet werden.</translation>
    </message>
    <message>
        <source>Cannot create directory: %1</source>
        <translation>Das Verzeichnis kann nicht angelegt werden: %1</translation>
    </message>
    <message>
        <source>Cannot copy collection file: %1</source>
        <translation>Die Katalogdatei kann nicht kopiert werden: %1</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Der Filter kann nicht registriert werden: %1</translation>
    </message>
    <message>
        <source>Cannot open documentation file %1!</source>
        <translation>Die Dokumentationsdatei kann nicht geöffnet werden: %1</translation>
    </message>
    <message>
        <source>The namespace %1 was not registered!</source>
        <translation>Der Namensraum %1 wurde nicht registriert.</translation>
    </message>
    <message>
        <source>Namespace %1 already exists!</source>
        <translation>Der Namensraum %1 existiert bereits.</translation>
    </message>
</context>
<context>
    <name>QHelpDBReader</name>
    <message>
        <source>Cannot open database &apos;%1&apos; &apos;%2&apos;: %3</source>
        <extracomment>The placeholders are: %1 - The name of the database which cannot be opened %2 - The unique id for the connection %3 - The actual error string</extracomment>
        <translation>Kann Datenbank nicht öffnen: &apos;%1&apos; &apos;%2&apos;: %3</translation>
    </message>
</context>
<context>
    <name>QHelpEngineCore</name>
    <message>
        <source>Cannot open documentation file %1: %2!</source>
        <translation>Die Dokumentationsdatei %1 kann nicht geöffnet werden: %2!</translation>
    </message>
    <message>
        <source>The specified namespace does not exist!</source>
        <translation>Der angegebene Namensraum existiert nicht.</translation>
    </message>
</context>
<context>
    <name>QHelpGenerator</name>
    <message>
        <source>Invalid help data!</source>
        <translation>Ungültige Hilfe-Daten.</translation>
    </message>
    <message>
        <source>No output file name specified!</source>
        <translation>Für die Ausgabe-Datei wurde kein Name angegeben.</translation>
    </message>
    <message>
        <source>Building up file structure...</source>
        <translation>Dateistruktur wird erzeugt...</translation>
    </message>
    <message>
        <source>The file %1 cannot be overwritten!</source>
        <translation>Die Datei %1 kann nicht überschrieben werden.</translation>
    </message>
    <message>
        <source>Cannot open data base file %1!</source>
        <translation>Die Datenbank-Datei %1 kann nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>Cannot register namespace %1!</source>
        <translation>Der Namensraum %1 kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Insert custom filters...</source>
        <translation>Benutzerdefinierte Filter einfügen...</translation>
    </message>
    <message>
        <source>Insert help data for filter section (%1 of %2)...</source>
        <translation>Hilfe-Daten für Filter-Sektion (%1 von %2) einfügen...</translation>
    </message>
    <message>
        <source>Documentation successfully generated.</source>
        <translation>Dokumentation erfolgreich generiert.</translation>
    </message>
    <message>
        <source>Some tables already exist!</source>
        <translation>Einige Tabellen existieren bereits.</translation>
    </message>
    <message>
        <source>Cannot create tables!</source>
        <translation>Tabellen können nicht erstellt werden.</translation>
    </message>
    <message>
        <source>Cannot register virtual folder!</source>
        <translation>Virtueller Order kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Insert files...</source>
        <translation>Dateien einfügen...</translation>
    </message>
    <message>
        <source>The file %1 does not exist! Skipping it.</source>
        <translation>Die Datei %1 existiert nicht. Wird übersprungen.</translation>
    </message>
    <message>
        <source>Cannot open file %1! Skipping it.</source>
        <translation>Die Datei %1 kann nicht geöffnet werden. Wird übersprungen.</translation>
    </message>
    <message>
        <source>The filter %1 is already registered!</source>
        <translation>Der Filter %1 ist bereits registriert.</translation>
    </message>
    <message>
        <source>Cannot register filter %1!</source>
        <translation>Der Filter %1 kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>Insert indices...</source>
        <translation>Indizes einfügen...</translation>
    </message>
    <message>
        <source>Insert contents...</source>
        <translation>Inhalt einfügen...</translation>
    </message>
    <message>
        <source>Cannot insert contents!</source>
        <translation>Inhalt kann nicht eingefügt werden.</translation>
    </message>
    <message>
        <source>Cannot register contents!</source>
        <translation>Inhalt kann nicht registriert werden.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; does not exist.</source>
        <translation>Die Datei &apos;%1&apos; existiert nicht.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; cannot be opened.</source>
        <translation>Die Datei &apos;%1&apos; kann nicht geöffnet werden.</translation>
    </message>
    <message>
        <source>File &apos;%1&apos; contains an invalid link to file &apos;%2&apos;</source>
        <translation>Die Datei &apos;%1&apos; enthält einen ungültigen Verweis auf die Datei &apos;%2&apos;</translation>
    </message>
    <message>
        <source>Invalid links in HTML files.</source>
        <translation>Es wurden ungültige Verweise in HTML-Dateien gefunden.</translation>
    </message>
</context>
<context>
    <name>QHelpProject</name>
    <message>
        <source>Unknown token in file &quot;%1&quot;.</source>
        <translation>Unbekanntes Token in der Datei &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Unknown token. Expected &quot;QtHelpProject&quot;!</source>
        <translation>Unbekanntes Token. &quot;QtHelpProject&quot; erwartet.</translation>
    </message>
    <message>
        <source>Error in line %1: %2</source>
        <translation>Fehler in Zeile %1: %2</translation>
    </message>
    <message>
        <source>Virtual folder has invalid syntax in file: &quot;%1&quot;</source>
        <translation>Der virtuelle Ordner hat in der Datei &quot;%1&quot; eine ungültige Syntax</translation>
    </message>
    <message>
        <source>Namespace &quot;%1&quot; has invalid syntax in file: &quot;%2&quot;</source>
        <translation>Der Namensraum &quot;%1&quot; hat in der Datei &quot;%2&quot; eine ungültige Syntax</translation>
    </message>
    <message>
        <source>Missing namespace in QtHelpProject file: &quot;%1&quot;</source>
        <translation>Fehlender Namensraum in der QtHelpProject-Datei: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Missing virtual folder in QtHelpProject file: &quot;%1&quot;</source>
        <translation>Fehlender virtueller Ordner in der QtHelpProject-Datei: &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The input file %1 could not be opened!</source>
        <translation>Die Eingabe-Datei %1 kann nicht geöffnet werden.</translation>
    </message>
</context>
<context>
    <name>QHelpSearchQueryWidget</name>
    <message>
        <source>Search for:</source>
        <translation>Suche nach:</translation>
    </message>
    <message>
        <source>Previous search</source>
        <translation>Vorige Suche</translation>
    </message>
    <message>
        <source>Next search</source>
        <translation>Nächste Suche</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Suche</translation>
    </message>
    <message>
        <source>Advanced search</source>
        <translation>Erweiterte Suche</translation>
    </message>
    <message>
        <source>words &lt;B&gt;similar&lt;/B&gt; to:</source>
        <translation>Worte &lt;B&gt;ähnlich&lt;/B&gt; zu:</translation>
    </message>
    <message>
        <source>&lt;B&gt;without&lt;/B&gt; the words:</source>
        <translation>&lt;B&gt;ohne&lt;/B&gt; die Wörter:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;exact phrase&lt;/B&gt;:</source>
        <translation>mit der &lt;B&gt;genauen Wortgruppe&lt;/B&gt;:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;all&lt;/B&gt; of the words:</source>
        <translation>mit &lt;B&gt;allen&lt;/B&gt; Wörtern:</translation>
    </message>
    <message>
        <source>with &lt;B&gt;at least one&lt;/B&gt; of the words:</source>
        <translation>mit &lt;B&gt;irgendeinem&lt;/B&gt; der Wörter:</translation>
    </message>
</context>
<context>
    <name>QHelpSearchResultWidget</name>
    <message numerus="yes">
        <source>%1 - %2 of %n Hits</source>
        <translation>
            <numerusform>%1 - %2 - Ein Treffer</numerusform>
            <numerusform>%1 - %2 von %n Treffern</numerusform>
        </translation>
    </message>
    <message>
        <source>0 - 0 of 0 Hits</source>
        <translation>0 - 0 von 0 Treffern</translation>
    </message>
</context>
</TS>
